@@ -60,8 +60,8 @@ def downstream_phase_detection(variants, segment, record, quality):
         # SNP.start grabs vcf positions in 0 index while vcfs are 1 indexed
         idx = variant.start - record.reference_start
 
-        parent1 = variant.gt_bases[0].split('/')[0]
-        parent2 = variant.gt_bases[1].split('/')[0]
+        parent1 = variant.gt_bases[0].split('/')[0].split('|')[0]
+        parent2 = variant.gt_bases[1].split('/')[0].split('|')[0]
 
         if parent1 == parent2: # ignore uninformative SNPs
             continue
@@ -93,36 +93,27 @@ def downstream_phase_detection(variants, segment, record, quality):
             parent1_match = segment[idx:idx + len(parent1)] == parent1
             parent2_match = segment[idx:idx + len(parent2)] == parent2
 
-            # always check parent haplotype that is longer first as
-            # most include the shorter haplotype thus the longer haplotype
-            # is harder to match
-            if len(parent1) > len(parent2):
-                if parent1_match:
-                    detection_results.append(('1', variant.start))
-                elif parent2_match:
-                    detection_results.append(('2', variant.start))
-                else:
-                    detection_results.append(('N', variant.start))
+            if parent1_match and not parent2_match:
+                detection_results.append(('1', variant.start, parent1))
+            elif parent2_match and not parent1_match:
+                detection_results.append(('2', variant.start, parent2))
+            elif parent1_match and parent2_match:
+                continue
             else:
-                if parent2_match:
-                    detection_results.append(('2', variant.start))
-                elif parent1_match:
-                    detection_results.append(('1', variant.start))
-                else:
-                    detection_results.append(('N', variant.start))
+                detection_results.append(('N', variant.start, None))
 
         else: # variant is a SNP
             if idx >= len(segment):
                 break
 
             if segment[idx] == parent1:
-                detection_results.append(('1', variant.start))
+                detection_results.append(('1', variant.start, parent1))
 
             elif segment[idx] == parent2:
-                detection_results.append(('2', variant.start))
+                detection_results.append(('2', variant.start, parent2))
 
             else:
-                detection_results.append(('N', variant.start))
+                detection_results.append(('N', variant.start, None))
 
     return detection_results
 
@@ -152,6 +143,9 @@ class Pair():
         else:
             self.rec_1 = record2
             self.rec_2 = record1
+        self.location = ''.join(f'{self.rec_1.reference_name}:\
+        {self.rec_1.reference_start}-\
+        {self.rec_2.reference_start + self.rec_2.query_alignment_length}'.split())
 
         self.vcf_filepath = vcf_filepath
 
@@ -161,10 +155,12 @@ class Pair():
         self.segment_2 = cigar(self.rec_2)
         self.variants_1 = None
         self.variants_2 = None
+        self.variants_filt = None
 
         # recombination event calling
         self.detection_1 = None
         self.detection_2 = None
+        self.detection = None
         self.no_match = None
         self.condensed = None
         self.masked_condensed = None
@@ -204,8 +200,9 @@ class Pair():
                     f'Condensed Masked: {self.masked_condensed} \n' + \
                     f'Masked Call: {self.masked_call} \n' + \
                     f'Midpoint: {self.get_midpoint()} \n' + \
-                    f'Variants Per Haplotype: {self.variants_per_haplotype} \n' + \
-                    f'Gene Conversion Length: {self.gene_conversion_len}'
+                    f'Variants Per Haplotype (Masked): {self.variants_per_haplotype} \n' + \
+                    f'Gene Conversion Length: {self.gene_conversion_len} \n' + \
+                    f'Min Variants In Haplotype: {self.min_variants_in_haplotype} \n' + \
         else:
             string = f'Record name: {self.rec_1.query_name} \n' + \
                     f'Read1: {self.rec_1.reference_name}:{self.rec_1.reference_start}' + \
@@ -303,14 +300,21 @@ class Pair():
         self.variants_2 = check_variants(
             vcf, self.rec_2.reference_name, self.rec_2.reference_start, 
             self.rec_2.reference_start + self.rec_2.query_alignment_length)
+        vcf.close()
 
         self.detection_1 = downstream_phase_detection(
             self.variants_1, self.segment_1, self.rec_1, quality)
         self.detection_2 = downstream_phase_detection(
             self.variants_2, self.segment_2, self.rec_2, quality)
+        self.detection = self.detection_1 + self.detection_2
+
+        # create condensed variant list with used variants for easy lookup
+        self.variants_filt = [
+            variant for variant in self.variants_1 + self.variants_2
+            if variant.POS in [v[1] + 1 for v in self.detection]]
 
         # set no_match variable if there are unmatched variants
-        self.no_match = bool('N' in self.detection_1 or 'N' in self.detection_2)
+        self.no_match = any([v[0] == 'N' for v in self.detection])
 
         # simplification of results
         # [(haplotype, beginning, end), ...]
@@ -328,7 +332,7 @@ class Pair():
             # different haplotype
             elif self.condensed[-1][0] != haplotype:
                 # middle of previous variant location and current variant
-                # gonna round down so it's not a decimal
+                # rounding down so it's not a decimal
                 midpoint = int((self.condensed[-1][2] + location) // 2)
                 self.condensed[-1][2] = midpoint
                 self.condensed.append([haplotype, midpoint, midpoint])
@@ -410,10 +414,10 @@ class Pair():
 
         # get the lowest number of variants a haplotype has -
         # splits variant list (e.g. ['1', '1', '2', '1']) and gets min variant count across haps
-        if 'no_phase_change' not in [self.call, self.masked_call]:
+        if 'no_phase_change' not in set([self.call, self.masked_call]):
             self.min_variants_in_haplotype = min(
                 len(list(grouper)) for value, grouper
-                in itertools.groupby([hap for hap, position in self.detection_1 + self.detection_2])
+                in itertools.groupby([hap for hap, position, allele in self.detection])
                 )
 
         # convert haplotypes 1/2/N to VCF sample names
@@ -477,6 +481,9 @@ class Pair():
             end = self.condensed[-1][1]
             self.midpoint = (start + end) / 2
 
+        # return in samtools format
+        self.midpoint = f'{self.rec_1.reference_name}:{round(self.midpoint)}'
+
         return self.midpoint
 
 
