@@ -43,7 +43,7 @@ def arg_parser():
         help='File to write to (default recomb_diagnosis)')
     parser.add_argument('-q', '--quality', required=False, type=int, default=30,
         help='Filter quality for individual bases in a sequence, default is 30')
-    parser.add_argument('--version', action='version', version='readcomb 0.0.9')
+    parser.add_argument('--version', action='version', version='readcomb 0.1.2')
 
     return parser
 
@@ -51,7 +51,7 @@ class SilentVCF:
     # helper class for check_variants that silences cyvcf2 warnings
     def __enter__(self):
         self._original_stderr = sys.stderr
-        sys.stderr = open(os.devnull, 'w')
+        sys.stderr = open(os.devnull, 'a')
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         sys.stderr.close()
@@ -81,14 +81,14 @@ def check_variants(vcf_file_obj, chromosome, left_bound, right_bound):
     # in order to keep code consistent
     region = f'{chromosome}:{left_bound+1}-{right_bound}'
     with SilentVCF():
-        records = [rec for rec in vcf_file_obj(region)]
+        records = [record for record in vcf_file_obj(region)]
     return records
 
 def cigar(record):
     """
     Realign the given query segment to its reference.
 
-    Rebuild the sequence using the query sequence and cigar tuple from the 
+    Rebuild the sequence using the query sequence and cigar tuple from the
     bam record to realign it with the reference sequence prior to variant matching
 
     Parameters
@@ -190,8 +190,8 @@ def phase_detection(variants, segment, record, args):
         # variant.start grabs vcf positions in 0 index while vcfs are 1 indexed
         idx = variant.start - record.reference_start
 
-        parent1 = variant.gt_bases[0].split('/')[0]
-        parent2 = variant.gt_bases[1].split('/')[0]
+        parent1 = variant.gt_bases[0].split('/')[0].split('|')[0]
+        parent2 = variant.gt_bases[1].split('/')[0].split('|')[0]
 
         # ignore uninformative variants
         if parent1 == parent2:
@@ -224,23 +224,14 @@ def phase_detection(variants, segment, record, args):
             parent1_match = segment[idx:idx + len(parent1)] == parent1
             parent2_match = segment[idx:idx + len(parent2)] == parent2
 
-            # always check parent haplotype that is longer first as
-            # most include the shorter haplotype thus the longer haplotype
-            # is harder to match
-            if len(parent1) > len(parent2):
-                if parent1_match:
-                    variant_lst.append('1')
-                elif parent2_match:
-                    variant_lst.append('2')
-                else:
-                    variant_lst.append('N')
+            if parent1_match and not parent2_match:
+                variant_lst.append('1')
+            elif parent2_match and not parent1_match:
+                variant_lst.append('2')
+            elif parent1_match and parent2_match:
+                continue # uninformative allele! 
             else:
-                if parent2_match:
-                    variant_lst.append('2')
-                elif parent1_match:
-                    variant_lst.append('1')
-                else:
-                    variant_lst.append('N')
+                variant_lst.append('N')
 
         else: # variant is a SNP
             if segment[idx] == parent1:
@@ -295,7 +286,7 @@ class Processor(Process):
         Start the ``Processor``
 
         ``run()`` is automatically called when the scheduler runs ``Processor.start()``,
-        this begins the operations of both the ``multiprocessing.Process()`` super 
+        this begins the operations of both the ``multiprocessing.Process()`` super
         class and ``Processor``.
 
         See ``check_variants()``, ``cigar()``, and ``phase_detection`` for
@@ -309,10 +300,10 @@ class Processor(Process):
             record_2 = pysam.AlignedSegment.fromstring(pair[1], self.header)
 
             variants_1 = check_variants(
-                self.vcf_file_obj, record_1.reference_name, record_1.reference_start, 
+                self.vcf_file_obj, record_1.reference_name, record_1.reference_start,
                 record_1.reference_start + record_1.query_alignment_length)
             variants_2 = check_variants(
-                self.vcf_file_obj, record_2.reference_name, record_2.reference_start, 
+                self.vcf_file_obj, record_2.reference_name, record_2.reference_start,
                 record_2.reference_start + record_2.query_alignment_length)
 
             self.counter_queue.put('seq')
@@ -410,7 +401,8 @@ class Counter(Process):
         runtime = str(datetime.timedelta(seconds=round(end - start)))
 
         # print counters to STDOUT
-        print('{} phase change reads pairs from total {} read pairs'.format(
+        print(f'[readcomb] completed filtering for {self.args.bam}')
+        print('{} phase change-containing read pairs from total {} read pairs'.format(
             self.counters['phase_change'], self.counters['seq']))
         print('{} reads had no-match variants'.format(self.counters['no_match']))
         print('{} reads did not have enough variants (> 0) to call'.format(
@@ -426,7 +418,7 @@ class Counter(Process):
             # convert argparse namespace to dictionary to be more easily manipulated
             args_dict = vars(self.args)
 
-            with open(args_dict, 'a') as f:
+            with open(self.args.log, 'a') as f:
                 if needs_header:
                     fieldnames = ['time',
                                 'phase_change_reads',
@@ -473,8 +465,14 @@ class Writer(Process):
         self.input_queue = input_queue
 
         pysam_obj = pysam.AlignmentFile(args.bam, 'r')
+        if args.out.endswith('.bam'):
+            print('[readcomb] WARNING: readcomb-filter only outputs .sam files')
+            args.out = args.out.replace('.bam', '.sam')
+            print(f'[readcomb] output will be written to {args.out}')
+        elif not args.out.endswith('.sam'):
+            args.out = args.out + '.sam'
         self.out = pysam.AlignmentFile(
-            args.out + '.sam', 'wh', template=pysam_obj)
+            args.out, 'wh', template=pysam_obj)
         self.header = pysam.AlignmentFile(args.bam, 'r').header
 
     def run(self):
@@ -516,7 +514,7 @@ def matepair_process():
 
     # idxstats on bam/bai file
     if not os.path.isfile(args.bam + '.bai'):
-        print('Bai file not found, continuing without progress bars')
+        print('[readcomb] bai file not provided - continuing without progress bars')
         args.pair_count = None
     else:
         stats = subprocess.check_output(['samtools', 'idxstats', args.bam])
@@ -532,7 +530,7 @@ def matepair_process():
     # pysam argument object
     bam = pysam.AlignmentFile(args.bam, 'r')
 
-    print('Creating processes')
+    print('[readcomb] creating processes')
     # set up counter and writer
     count_input = Queue()
     # daemon causes other sub-processes to auto shutdown if main process is interrupted
@@ -557,7 +555,7 @@ def matepair_process():
     prev_record = None
     process_idx = 0
 
-    print('Processes created')
+    print('[readcomb] processes created')
 
     for record in bam:
         # check if record is in a proper pair
